@@ -64,4 +64,54 @@ public class LzFixedNumberField  extends JTextField {
 			super.insertString(offs, str, a);
 		}
 	}
+
+	/**
+	 * intǂԂ
+	 * @return
+	 */
+	public boolean isInt() {
+		try {
+			Integer.parseInt(getText());
+			return true;
+		} catch (NumberFormatException e) {
+			return false;
+		}
+	}
+
+	/**
+	 * int̒lԂ
+	 * @return
+	 */
+	public int getInt() {
+		try {
+			return Integer.parseInt(getText());
+		} catch (NumberFormatException e) {
+			return -1;
+		}
+	}
+
+	/**
+	 * doubleǂԂ
+	 * @return
+	 */
+	public boolean isDouble() {
+		try {
+			Double.parseDouble(getText());
+			return true;
+		} catch (NumberFormatException e) {
+			return false;
+		}
+	}
+
+	/**
+	 * double̒lԂ
+	 * @return
+	 */
+	public double getDouble() {
+		try {
+			return Double.parseDouble(getText());
+		} catch (NumberFormatException e) {
+			return -1d;
+		}
+	}
 }
\ No newline at end of file
